# amqp_framework

Awesome producers and consumers powered by aio_pika

### Installation

```bash
pip install amqp-framework
```

### Example usage

- https://github.com/aobcvr/rpg_quest_accounts

### License

[MIT](https://en.wikipedia.org/wiki/MIT_License)

### TODO:

- [ ] Documentation
- [ ] Examples folder
